==> pogamut-base-3.2.0-20110310.094729-46-test-sources.jar: cz/cuni/amis/pogamut/multi/worldview/Test03_BatchAwareWorldView_2Agents.java <==
package cz.cuni.amis.pogamut.multi.worldview;

import org.junit.After;
import org.junit.Test;

import cz.cuni.amis.pogamut.multi.utils.timekey.TimeKey;
import cz.cuni.amis.pogamut.multi.utils.timekey.TimeKeyManager;
				
public class Test03_BatchAwareWorldView_2Agents extends BatchAwareWorldViewTest {

	@Test
	public void test1() {
		// WILL WORK OK
		runTest(
			2,    // int agents, 
			100,  // int logicCycles, 
			10,    // long logicDuration, 
			10,   // int objectsPerBatch, 
			50,    // long batchDuration, 
			20000 // long timeoutMillis
		);
	}
	
	@Test
	public void test2() {
		// WILL WORK OK
		runTest(
			2,     // int agents, 
			100,   // int logicCycles, 
			50,    // long logicDuration, 
			10,    // int objectsPerBatch, 
			100,   // long batchDuration, 
			30000  // long timeoutMillis
		);
	}
	
	@Test
	public void test3() {
		// WILL WORK OK
		runTest(
			2,     // int agents, 
			100,   // int logicCycles, 
			100,   // long logicDuration, 
			10,    // int objectsPerBatch, 
			240,   // long batchDuration, 
			40000  // long timeoutMillis
		);
	}
	
//	@Test
//	public void testThatFails() {
//		// WILL FAIL
//		runTest(
//			2,    // int agents, 
//			100,  // int logicCycles, 
//			10,   // long logicDuration, 
//			10,   // int objectsPerBatch, 
//			2,    // long batchDuration, 
//			20000 // long timeoutMillis
//		);
//	}
	
	@Override
	@After
	public void afterTest() {
		try {
			TimeKeyManager.get().unlockAll();
		} catch (Exception e) {			
		}
		try {
			TimeKey.clear();
		} catch (Exception e) {			
		}
	}
	
}

==> pogamut-base-3.2.1-20110331.062421-23-test-sources.jar: cz/cuni/amis/pogamut/multi/worldview/Test03_BatchAwareWorldView_2Agents.java <==
package cz.cuni.amis.pogamut.multi.worldview;

import org.junit.Test;

				
public class Test03_BatchAwareWorldView_2Agents extends BatchAwareWorldViewTest {

	@Test
	public void test1() {
		// WILL WORK OK
		runTest(
			2,     // int agents, 
			100,   // int logicCycles, 
			10,    // long logicDuration, 
			10,    // int objectsPerBatch, 
			50,    // long batchDuration, 
			300000,// long timeoutMillis
			true   // sync batches
		);
	}
	
	@Test
	public void test2() {
		// WILL WORK OK
		runTest(
			2,     // int agents, 
			100,   // int logicCycles, 
			50,    // long logicDuration, 
			10,    // int objectsPerBatch, 
			100,   // long batchDuration, 
			300000,// long timeoutMillis
			true   // sync batches
		);
	}
	
	@Test
	public void test3() {
		// WILL WORK OK
		runTest(
			2,     // int agents, 
			100,   // int logicCycles, 
			100,   // long logicDuration, 
			10,    // int objectsPerBatch, 
			240,   // long batchDuration, 
			300000,// long timeoutMillis
			true   // sync batches
		);
	}
	
	@Test
	public void test4() {
		runTest(
			2,     // int agents, 
			100,   // int logicCycles, 
			10,    // long logicDuration, 
			10,    // int objectsPerBatch, 
			2,     // long batchDuration, 
			300000,// long timeoutMillis
			true   // sync batches
		);
	}
	
//	@Test
//	public void testThatFails() {
//		// WILL FAIL
//		runTest(
//			2,     // int agents, 
//			100,   // int logicCycles, 
//			10,    // long logicDuration, 
//			10,    // int objectsPerBatch, 
//			2,     // long batchDuration, 
//			300000,// long timeoutMillis
//          false  // sync batches
//		);
//	}

	
}
